@@ -110,8 +110,9 @@ public class StorageHubClientService {
 	 * @param withAccounting the with accounting
 	 * @param withMapProperties the with map properties
 	 * @return the children
+	 * @throws Exception 
 	 */
-	public List<? extends Item> getChildren(String id, boolean withAccounting, boolean withMapProperties){
+	public List<? extends Item> getChildren(String id, boolean withAccounting, boolean withMapProperties) throws Exception{
 		setContextProviders(scope, authorizationToken);
 		logger.trace("Requesting getChildren for id: "+id+" [withAccounting: "+withAccounting+", withMapProperties: "+withMapProperties+"]");
 		ListResolverTyped resolverTyped = shcClient.open(id).asFolder().list();
@@ -135,8 +136,9 @@ public class StorageHubClientService {
 	 * @param withAccounting the with accounting
 	 * @param withMapProperties the with map properties
 	 * @return the filtered children
+	 * @throws Exception 
 	 */
-	public List<? extends Item> getFilteredChildren(String id, Class<? extends Item> aType, boolean withAccounting, boolean withMapProperties){
+	public List<? extends Item> getFilteredChildren(String id, Class<? extends Item> aType, boolean withAccounting, boolean withMapProperties) throws Exception{
 		setContextProviders(scope, authorizationToken);
 
 		ListResolver resolverTyped = shcClient.open(id).asFolder().list().ofType(aType);
@@ -243,8 +245,9 @@ public class StorageHubClientService {
 	 *
 	 * @param itemId the item id
 	 * @return the parents
+	 * @throws Exception 
 	 */
-	public List<? extends Item> getParents(String itemId) {
+	public List<? extends Item> getParents(String itemId) throws Exception {
 		setContextProviders(scope, authorizationToken);
 		ListResolver toReturn = shcClient.open(itemId).asItem().getAnchestors();
 		if(toReturn==null || toReturn.getItems()==null){
@@ -404,8 +407,9 @@ public class StorageHubClientService {
 	 *
 	 * @param itemId the item id
 	 * @return the item children count
+	 * @throws Exception 
 	 */
-	public int getItemChildrenCount(String itemId) {
+	public int getItemChildrenCount(String itemId) throws Exception {
 
 		setContextProviders(scope, authorizationToken);
 		ItemManagerClient client = AbstractPlugin.item().build();
